==> flutter_local_notifications-0.3.7.tar.gz: lib/src/platform_specifics/android/styles/inbox_style_information.dart <==
part of flutter_local_notifications;

/// Used to pass the content for an Android notification displayed using the inbox style
class InboxStyleInformation extends DefaultStyleInformation {
  /// Overrides ContentTitle in the big form of the template.
  final String contentTitle;

  /// Set the first line of text after the detail section in the big form of the template.
  final String summaryText;

  /// The lines that form part of the digest section for inbox-style notifications
  List<String> lines;

  /// Specifies if the lines should have formatting applied through HTML markup
  final bool htmlFormatLines;

  /// Specifies if the overridden ContentTitle should have formatting applied through HTML markup
  final bool htmlFormatContentTitle;

  /// Specifies if formatting should be applied to the first line of text after the detail section in the big form of the template.
  final bool htmlFormatSummaryText;

  InboxStyleInformation(this.lines,
      {this.htmlFormatLines = false,
      this.contentTitle,
      this.htmlFormatContentTitle = false,
      this.summaryText,
      this.htmlFormatSummaryText = false,
      bool htmlFormatContent = false,
      bool htmlFormatTitle = false})
      : super(htmlFormatContent, htmlFormatTitle);

  Map<String, dynamic> toMap() {
    var styleJson = super.toMap();

    var bigTextStyleJson = <String, dynamic>{
      'contentTitle': contentTitle,
      'htmlFormatContentTitle': htmlFormatContentTitle,
      'summaryText': summaryText,
      'htmlFormatSummaryText': htmlFormatSummaryText,
      'lines': lines ?? new List<String>(),
      'htmlFormatLines': htmlFormatLines
    };
    styleJson.addAll(bigTextStyleJson);
    return styleJson;
  }
}

==> flutter_local_notifications-0.9.1.tar.gz: lib/src/platform_specifics/android/styles/inbox_style_information.dart <==
import 'default_style_information.dart';

/// Used to pass the content for an Android notification displayed using the inbox style
class InboxStyleInformation extends DefaultStyleInformation {
  /// Overrides ContentTitle in the big form of the template.
  final String contentTitle;

  /// Set the first line of text after the detail section in the big form of the template.
  final String summaryText;

  /// The lines that form part of the digest section for inbox-style notifications
  List<String> lines;

  /// Specifies if the lines should have formatting applied through HTML markup
  final bool htmlFormatLines;

  /// Specifies if the overridden ContentTitle should have formatting applied through HTML markup
  final bool htmlFormatContentTitle;

  /// Specifies if formatting should be applied to the first line of text after the detail section in the big form of the template.
  final bool htmlFormatSummaryText;

  InboxStyleInformation(this.lines,
      {this.htmlFormatLines = false,
      this.contentTitle,
      this.htmlFormatContentTitle = false,
      this.summaryText,
      this.htmlFormatSummaryText = false,
      bool htmlFormatContent = false,
      bool htmlFormatTitle = false})
      : super(htmlFormatContent, htmlFormatTitle);

  Map<String, dynamic> toMap() {
    var styleJson = super.toMap();

    var bigTextStyleJson = <String, dynamic>{
      'contentTitle': contentTitle,
      'htmlFormatContentTitle': htmlFormatContentTitle,
      'summaryText': summaryText,
      'htmlFormatSummaryText': htmlFormatSummaryText,
      'lines': lines ?? List<String>(),
      'htmlFormatLines': htmlFormatLines
    };
    styleJson.addAll(bigTextStyleJson);
    return styleJson;
  }
}
